@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# $Id: throttled_ftpd.py 573 2009-04-08 04:26:33Z billiejoex $
+# $Id: throttled_ftpd.py 757 2010-11-08 09:51:04Z g.rodola $
 
 """An FTP server which uses the ThrottledDTPHandler class for limiting the
 speed of downloads and uploads.
@@ -10,7 +10,7 @@ import os
 from pyftpdlib import ftpserver
 
 
-if __name__ == '__main__':
+def main():
     authorizer = ftpserver.DummyAuthorizer()
     authorizer.add_user('user', '12345', os.getcwd(), perm='elradfmw')
     authorizer.add_anonymous(os.getcwd())
@@ -26,3 +26,7 @@ if __name__ == '__main__':
 
     ftpd = ftpserver.FTPServer(('', 21), ftp_handler)
     ftpd.serve_forever()
+
+if __name__ == '__main__':
+    main()
+
